import React from 'react';
import { ComponentStory, ComponentMeta } from '@storybook/react';
import { RawJSONVis } from './rawjsonvis';

import { Provider } from 'react-redux';
import { configureStore, createSlice } from '@reduxjs/toolkit';

import graphQueryResultSlice, {
  assignNewGraphQueryResult,
  resetGraphQueryResults,
} from '../../../../../../libs/shared/data-access/store/src/lib/graphQueryResultSlice';

export default {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'RawJSONVIS',
  component: RawJSONVis,
  decorators: [
    (story) => (
      <div style={{ padding: '3rem' }}>
        <Provider store={Mockstore}>{story()}</Provider>
      </div>
    ),
  ],
} as ComponentMeta<typeof RawJSONVis>;

const Template: ComponentStory<typeof RawJSONVis> = (args) => (
  <RawJSONVis {...args} />
);

// A super-simple mock of a redux store
const Mockstore = configureStore({
  reducer: {
    graphQueryResult: graphQueryResultSlice,
  },
});

export const TestWithData = Template.bind({});
TestWithData.args = {
  loading: false,
};
TestWithData.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(
    assignNewGraphQueryResult({
      nodes: [
        { id: 'agent/007', attributes: { name: 'Daniel Craig' } },
        { id: 'villain', attributes: { name: 'Le Chiffre' } },
      ],
      links: [],
    })
  );
};

export const Loading = Template.bind({});
Loading.args = {
  loading: true,
};

export const Empty = Template.bind({});
Empty.args = {
  // Shaping the stories through args composition.
  // Inherited data coming from the Loading story.
  ...Loading.args,
  loading: false,
};
Empty.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(resetGraphQueryResults());
};
